Networked programs
------------------

While many of the examples in this book have focused on reading files
and looking for data in those files, there are many different sources of 
information when one considers the Internet.

In this chapter we will pretend to be a web browser and retrieve web
pages using the HyperText Transfer Protocol (HTTP). Then we will read
through the web page data and parse it.